# augment.spectrogram

## CropTime

::: fastaudio.augment.spectrogram.CropTime
    :docstring:

## MaskFreq

::: fastaudio.augment.spectrogram.MaskFreq
    :docstring:


## MaskTime

::: fastaudio.augment.spectrogram.MaskTime
    :docstring:

## SGRoll

::: fastaudio.augment.spectrogram.SGRoll
    :docstring:

## Delta

::: fastaudio.augment.spectrogram.Delta
    :docstring:

## TfmResize

::: fastaudio.augment.spectrogram.TfmResize
    :docstring:
